@@ -904,10 +904,12 @@ class DetectionsCollection(dict):
     def save_misses(self, save_dir: str, fp_threshold: float, fn_threshold: float, drawer_options={}):
         '''
         Calls get_misses and saves them on disk (drawings) for visual inspection
-        :param save_dir:
-        :param fp_threshold:
-        :param fn_threshold:
-        :param drawer_options:
+        :param save_dir: dir to save misses to
+        :param fp_threshold: False-Positive threshold. All predicted boxes with confidence higher then this threshold
+        and no matching ground-truth are considered as FP. Lower value - tougher.
+        :param fn_threshold: False-Negative threshold. Predicted boxes are matched to GT only if their confidence
+        higher than this threshold. Otherwise GT counted as False Negative. Higher value - tougher.
+        :param drawer_options: default fine
         :return:
         '''
         from syncvtools.utils.draw_detections import DrawDetections
