@@ -3,62 +3,80 @@ from syncvtools.data.image import ImgSize
 import numpy as np
 
 
-def normalize_bbox(bbox: Tuple[int, int, int, int], img_size: Tuple[int, int]) -> Tuple[float, float, float, float]:
+def normalize_bbox(bbox: Union[Tuple[int, int, int, int],np.ndarray], img_size: Tuple[int, int]) -> Union[Tuple[float, float, float, float],np.ndarray]:
     '''
     Takes x1,y1,x2,y2 in int and converts it into float32 0..1
     :param bbox: x1,y1,x2,y2 in int
     :param img_size: (w,h) in int
     :return: Normalized x1,y1,x2,y2 in float32 in range 0..1
     '''
-    if bbox is None or len(bbox) < 4 or len(bbox) > 5:
-        raise ValueError("Bbox is either None or not a tuple of size 4,5: (xmin, ymin, xmax, ymax)")
-
     img_size = ImgSize(width=img_size[0], height=img_size[1])
-    norm_coords = (float(bbox[0] / img_size.width), float(bbox[1] / img_size.height), float(bbox[2] / img_size.width),
-                   float(bbox[3] / img_size.height))
-    for coord in norm_coords:
-        if coord < 0 or coord > 1:
-            raise ValueError("Norm coordinates should be [0;1]: {}".format(bbox[:4]))
+    if isinstance(bbox, np.ndarray) and len(bbox.shape) in(2,3):
+        norm_coords = np.asarray(bbox,dtype=np.float32)
+        norm_coords[...,0:3:2] /= img_size.width
+        norm_coords[...,1:4:2] /= img_size.height
+        if len(norm_coords[(norm_coords<0) | (norm_coords>1)])>0: #during convert there should be no computational errors
+            raise ValueError("Norm coordinates should be [0,1]: {}".format(norm_coords))
+    else:
+        if bbox is None or len(bbox) < 4 or len(bbox) > 5:
+            raise ValueError("Bbox is either None or not a tuple of size 4,5: (xmin, ymin, xmax, ymax)")
+        norm_coords = (float(bbox[0] / img_size.width), float(bbox[1] / img_size.height), float(bbox[2] / img_size.width),
+                       float(bbox[3] / img_size.height))
+        for coord in norm_coords:
+            if coord < 0 or coord > 1:
+                raise ValueError("Norm coordinates should be [0;1]: {}".format(bbox[:4]))
     return norm_coords
 
 
-def denormalize_bbox(bbox: Tuple[float, float, float, float], img_size: Tuple[int, int]) -> Tuple[int, int, int, int]:
+def denormalize_bbox(bbox: Union[Tuple[float, float, float, float],np.ndarray], img_size: Tuple[int, int]) -> Union[Tuple[int, int, int, int],np.ndarray]:
     '''
     Takes x1,y1,x2,y2 in float32 0..1 and converts it into int
     :param bbox: x1,y1,x2,y2 in float32 0..1 rnage
     :param img_size: (w,h) in int
     :return: Normalized x1,y1,x2,y2 in int
     '''
-
     def cl(v, mn, mx):
         return max(min(v, mx), mn)
-
     # just to validate width/height
     img_size = ImgSize(width=img_size[0], height=img_size[1])
     bbox = validate_norm_coords(bbox=bbox)
-    abs_coords = bbox[0] * img_size.width, bbox[1] * img_size.height, bbox[2] * img_size.width, bbox[
-        3] * img_size.height
-    abs_coords = list(map(int, map(round, abs_coords)))
-    abs_coords = (cl(abs_coords[0], 0, img_size.width - 1),
-                  cl(abs_coords[1], 0, img_size.height - 1),
-                  cl(abs_coords[2], 0, img_size.width - 1),
-                  cl(abs_coords[3], 0, img_size.height - 1))
+    if isinstance(bbox, np.ndarray) and len(bbox.shape) in(2,3):
+        abs_coords = np.asarray(bbox, dtype=np.float32)
+        abs_coords[...,0:3:2] *= img_size.width
+        abs_coords[...,1:4:2] *= img_size.height
+        abs_coords[..., 0:3:2] = np.clip(abs_coords[..., 0:3:2], a_min=0, a_max=img_size.width)
+        abs_coords[..., 1:4:2] = np.clip(abs_coords[..., 1:4:2], a_min=0, a_max=img_size.height)
+    else:
+        abs_coords = bbox[0] * img_size.width, bbox[1] * img_size.height, bbox[2] * img_size.width, bbox[
+            3] * img_size.height
+        abs_coords = list(map(int, map(round, abs_coords)))
+        abs_coords = (cl(abs_coords[0], 0, img_size.width - 1),
+                      cl(abs_coords[1], 0, img_size.height - 1),
+                      cl(abs_coords[2], 0, img_size.width - 1),
+                      cl(abs_coords[3], 0, img_size.height - 1))
     return abs_coords
 
 
-def validate_norm_coords(bbox: Tuple[float, float, float, float]):
+def validate_norm_coords(bbox: Union[Tuple[float, float, float, float],np.ndarray]):
     '''
     Validates that normalized coordinates are in 0..1 range.
     Some small epsilon is allowed and fixed to sharp 0/1.
     :param bbox:
     :return:
     '''
-    if bbox is None or len(bbox) != 4:
-        raise ValueError("Bbox should take a tuple of float (x1,y1,x2,y2)")
-    for coord in bbox[:4]:
-        if coord < (0 - 1e-4) or coord > (1 + 1e-4):
-            raise ValueError("Norm coordinates should be [0;1]: {}".format(bbox[:4]))
-    return (max(0, bbox[0]), min(1, bbox[1]), max(0, bbox[2]), min(1, bbox[3]))
+
+    if isinstance(bbox, np.ndarray) and len(bbox.shape) in(2,3):
+        if len(bbox[(bbox < -1e-4) | (bbox > (1+1e-4))]) > 0:
+            raise ValueError("Norm coordinates should be [0;1]: {}".format(bbox))
+        return np.clip(bbox,a_min=0.0,a_max=1.0)
+
+    else:
+        if bbox is None or len(bbox) != 4:
+            raise ValueError("Bbox should take a tuple of float (x1,y1,x2,y2)")
+        for coord in bbox[:4]:
+            if coord < (0 - 1e-4) or coord > (1 + 1e-4):
+                raise ValueError("Norm coordinates should be [0;1]: {}".format(bbox[:4]))
+        return (max(0, bbox[0]), min(1, bbox[1]), max(0, bbox[2]), min(1, bbox[3]))
 
 
 def abs_x1y1x2y2_to_abs_x1y1wh(box_coords) -> Union[list, tuple, np.ndarray]:
@@ -81,6 +99,46 @@ def abs_x1y1x2y2_to_abs_x1y1wh(box_coords) -> Union[list, tuple, np.ndarray]:
         return box_coords
 
 
+def abs_x1y1x2y2_to_norm_y1x1y2x1(box_coords, img_size: Tuple[int, int]) -> Union[list, tuple, np.ndarray]:
+    '''
+    converting from synapse to TF Obje Det API
+    :param box_coords: x1,y1,x2,y2 abs list/tuple or np.array of shape (N,4)
+    :return: norm y1,x1,y2,x2 or np.array of shape (N,4)
+    '''
+    box_coords = normalize_bbox(box_coords,img_size=img_size)
+    if not isinstance(box_coords, np.ndarray):
+        assert len(box_coords) == 4
+        x1, y1, x2, y2 = box_coords
+        return (y1,x1,y2,x2)
+    else:
+        box_coords_tf = np.empty_like(box_coords)
+        box_coords_tf[...,1] =  box_coords[...,0]
+        box_coords_tf[..., 0] = box_coords[..., 1]
+        box_coords_tf[..., 2] = box_coords[..., 3]
+        box_coords_tf[..., 3] = box_coords[..., 2]
+        return box_coords_tf
+
+
+def norm_y1x1y2x1_to_abs_x1y1x2y2(box_coords, img_size: Tuple[int, int]) -> Union[list, tuple, np.ndarray]:
+    '''
+    converting from TF Obje Det API to standard Synapse
+    :param box_coords: norm y1,x1,y2,x2 or np.array of shape (N,4)
+    :return: x1,y1,x2,y2 abs list/tuple or np.array of shape (N,4)
+    '''
+    box_coords = denormalize_bbox(box_coords,img_size=(img_size[1],img_size[0])) #since input format is y,x
+    if not isinstance(box_coords, np.ndarray):
+        assert len(box_coords) == 4
+        y1, x1, y2, x2 = box_coords
+        return (x1,y1,x2,y2)
+    else:
+        box_coords_tf = np.empty_like(box_coords)
+        box_coords_tf[..., 1] = box_coords[..., 0]
+        box_coords_tf[..., 0] = box_coords[..., 1]
+        box_coords_tf[..., 2] = box_coords[..., 3]
+        box_coords_tf[..., 3] = box_coords[..., 2]
+        return box_coords_tf
+
+
 def abs_x1y1wh_to_abs_x1y1x2y2(box_coords) -> Union[list, tuple, np.ndarray]:
     '''
     converting from MSCOCO to Synapse
@@ -353,7 +411,7 @@ def box_fusion(boxes_list_by_model, points_list_by_model=None):
         avg_np = np.empty(shape=(len(L_box), 4))
         score_np = np.empty(shape=(len(L_box)))
         for i in range(len(L_box)):
-            L_box_np = np.asarray(L_box[i])  # [num,score,x1,y1,x2,y2]
+            L_box_np = np.array(L_box[i])  # [num,score,x1,y1,x2,y2]
             box_set_score = L_box_np[:, 0:1]
             box_set = L_box_np[:, 1:] * box_set_score
             box_set = np.sum(box_set, axis=0)
@@ -551,4 +609,12 @@ def iou_run_norm(bboxes1, bboxes2):
     boxAArea = (x12 - x11) * (y12 - y11)
     boxBArea = (x22 - x21) * (y22 - y21)
     iou = interArea / (boxAArea + np.transpose(boxBArea) - interArea)
-    return iou
\ No newline at end of file
+    return iou
+
+
+if __name__ == '__main__':
+    boxes = np.asarray( [ [[100,12,236, 346],[11,25,266,234]] ])
+    boxes_norm = abs_x1y1x2y2_to_norm_y1x1y2x1(box_coords=boxes, img_size=(500,350))
+    print(boxes_norm)
+    boxes_abs = norm_y1x1y2x1_to_abs_x1y1x2y2(box_coords=boxes_norm, img_size=(500,350))
+    print(boxes_abs)
