@@ -2,7 +2,7 @@
 Exports data into from native classes into different formats
 '''
 
-from typing import List, Dict, Any, Callable
+from typing import List, Dict, Any, Callable, Tuple
 from syncvtools.data.image import Image
 from syncvtools.data.detections import DetectionEntity, DetectionsCollection, ImageLevelDetections
 import cv2, os, glob, json, hashlib
@@ -385,3 +385,19 @@ class COCODetectionsExport:
                     results.append(inst)
         ft.json_object_to_file(path_src=out_json_path, data_obj=results)
         logging.info("{} instances written to file".format(len(results)))
+
+class CSVExport:
+    '''
+    Converts to simple CSV format: imgs/img_001.jpg,837,346,981,456,cow
+    Returns: img_np, array equal to csv row, relative path to save image to
+    '''
+    @staticmethod
+    def convert_one(img_det: ImageLevelDetections, img_key: str, img_dir: str = "") -> Tuple[List, str]:
+        # IMAGE
+        img_path = os.path.join(img_dir,"{}.png".format(img_key))
+        res = []
+        for gt in img_det.ground_truth:
+            bbox_coords = gt.bbox.bbox_abs
+            bbox_label = gt.label_text
+            res.append([img_path,] + list(bbox_coords) + [bbox_label,])
+        return res, img_path
\ No newline at end of file
