@@ -211,7 +211,6 @@ class TFRecords:
     '''
 
     @staticmethod
-    @DeprecationWarning
     def record_to_object(decoder, tf_one_record, is_decoded=False) -> Tuple[str, ImageLevelDetections]:
         '''
         Converts one raw TF record to our internal detection object.
@@ -409,7 +408,7 @@ class TFRecords:
         return res
 
     @staticmethod
-    def to_det_col_iter(tfrecord_src, shuffle=False):
+    def to_det_col_iter(tfrecord_src, shuffle=False, return_encoded=False):
         '''
         For big TF records this one can be used as iterator:
         for img_key, img_obj in this_func():
@@ -420,7 +419,9 @@ class TFRecords:
 
         def process_fn(value):
             """Sets up tf graph that decodes, transforms and pads input data."""
-            processed_tensors = decoder.decode(value)
+            processed_tensors = value
+            if not return_encoded:
+                processed_tensors = decoder.decode(value)
             return processed_tensors
 
         tf = dep('tf')
@@ -448,9 +449,12 @@ class TFRecords:
         logging.debug("Start tf record iteration..")
         try:
             while True:
-                decoded = sess.run(el)
-                key, img_obj = TFRecords.record_to_object(decoder=None, tf_one_record=decoded, is_decoded=True)
-                yield key, img_obj
+                tf_entity = sess.run(el)
+                if return_encoded:
+                    yield tf_entity
+                else:
+                    key, img_obj = TFRecords.record_to_object(decoder=None, tf_one_record=tf_entity, is_decoded=True)
+                    yield key, img_obj
         except tf.errors.OutOfRangeError as e:
             pass
         logging.debug("Finished tf record iteration..")
